@@ -24,7 +24,7 @@ VERSION='0.8'
 # Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 # MA 02110-1301, USA.
 #
-# Install a virtual debian server (vserver) from a debian HTTP/FTP archive
+# Install a virtual Debian server (vserver) from a Debian HTTP/FTP archive
 #
 # ----------------------------------------------------------------
 # Configurable items:
@@ -61,15 +61,15 @@ REMOVE_PACKAGES="lilo,makedev,nfs-kernel-server,lpr"
 # otherwise dpkg will detect whether we are i386/powerpc/sparc/etc
 ARCH=""
 
-# Which debian distribution
+# Which Debian distribution
 # (warning: this has only been tested with
 #  woody, sarge, etch, lenny and squeeze)
 DIST="squeeze"
 
-# Local or nearest location of a debian mirror (must include the `/debian')
+# Local or nearest location of a Debian mirror (must include the `/debian')
 MIRROR="http://ftp.uk.debian.org/debian"
 
-# debian-non-US mirror (must include the '/debian-non-US', only used for woody)
+# Debian-non-US mirror (must include the '/debian-non-US', only used for woody)
 MIRROR_NON_US="http://non-us.debian.org/debian-non-US"
 
 # mirror for security updates
@@ -288,7 +288,7 @@ parse_args ()
 				MIRROR="$2"
 				;;
 			    *)
-				echo "${0##*/} error: $1 requires a debian mirror"  1>&2
+				echo "${0##*/} error: $1 requires a Debian mirror"  1>&2
 				echo 'e.g. "http://ftp.uk.debian.org/debian"' 1>&2
 				exit 1
 				;;
